@@ -52,7 +52,6 @@ package com.openexchange.sessionstorage.hazelcast.osgi;
 import java.util.Dictionary;
 import java.util.Hashtable;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.BundleException;
 import org.osgi.framework.ServiceReference;
@@ -63,18 +62,17 @@ import org.osgi.service.event.EventHandler;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
 import com.hazelcast.config.Config;
 import com.hazelcast.config.MapConfig;
-import com.hazelcast.core.HazelcastException;
 import com.hazelcast.core.HazelcastInstance;
-import com.openexchange.exception.OXException;
 import com.openexchange.hazelcast.configuration.HazelcastConfigurationService;
-import com.openexchange.log.LogFactory;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.sessionstorage.SessionStorageService;
 import com.openexchange.sessionstorage.hazelcast.HazelcastSessionStorageService;
 import com.openexchange.sessionstorage.hazelcast.Services;
+import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.ThreadPoolService;
+import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 
 /**
  * {@link HazelcastSessionStorageActivator}
@@ -84,7 +82,8 @@ import com.openexchange.threadpool.ThreadPoolService;
  */
 public class HazelcastSessionStorageActivator extends HousekeepingActivator {
 
-    private static Log LOG = LogFactory.getLog(HazelcastSessionStorageActivator.class);
+    /** The logger */
+    static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HazelcastSessionStorageActivator.class);
 
     @Override
     protected Class<?>[] getNeededServices() {
@@ -125,14 +124,30 @@ public class HazelcastSessionStorageActivator extends HousekeepingActivator {
                         @Override
                         public void handleEvent(Event osgiEvent) {
                             if (null != osgiEvent && SessiondEventConstants.TOPIC_TOUCH_SESSION.equals(osgiEvent.getTopic())) {
-                                Session touchedSession = (Session)osgiEvent.getProperty(SessiondEventConstants.PROP_SESSION);
+                                final Session touchedSession = (Session)osgiEvent.getProperty(SessiondEventConstants.PROP_SESSION);
                                 if (null != touchedSession && null != touchedSession.getSessionID()) {
-                                    try {
-                                        sessionStorageService.touch(touchedSession.getSessionID());
-                                    } catch (OXException e) {
-                                        LOG.warn("error handling OSGi event", e);
-                                    } catch (HazelcastException e) {
-                                        LOG.warn("error handling OSGi event", e);
+                                    // Handle session-touched event asynchronously if possible
+                                    final ThreadPoolService threadPool = getService(ThreadPoolService.class);
+                                    if (null == threadPool) {
+                                        try {
+                                            sessionStorageService.touch(touchedSession.getSessionID());
+                                        } catch (final Exception e) {
+                                            LOG.warn("error handling OSGi event", e);
+                                        }
+                                    } else {
+                                        final AbstractTask<Void> task = new AbstractTask<Void>() {
+
+                                            @Override
+                                            public Void call() throws Exception {
+                                                try {
+                                                    sessionStorageService.touch(touchedSession.getSessionID());
+                                                } catch (final Exception e) {
+                                                    LOG.warn("error handling OSGi event", e);
+                                                }
+                                                return null;
+                                            }
+                                        };
+                                        threadPool.submit(task, CallerRunsBehavior.<Void> getInstance());
                                     }
                                 }
                             }
@@ -209,7 +224,7 @@ public class HazelcastSessionStorageActivator extends HousekeepingActivator {
         if (null != mapConfigs && 0 < mapConfigs.size()) {
             for (String mapName : mapConfigs.keySet()) {
                 if (mapName.startsWith("sessions-")) {
-                    LOG.info("Using distributed map '" + mapName + "'.");
+                    LOG.info("Using distributed map '{}'.", mapName);
                     return mapName;
                 }
             }
